import { enableLocationRequest, isEnabled } from "@nativescript/geolocation";
import { Utils } from "@nativescript/core";
import { getSeenWifiApsFrom } from "./parsers";
export class AndroidWifiScanAdapter {
    constructor(wifiManager = Utils.android
        .getApplicationContext()
        .getSystemService(android.content.Context.WIFI_SERVICE)) {
        this.wifiManager = wifiManager;
    }
    isReady() {
        return isEnabled();
    }
    prepare() {
        return enableLocationRequest(false, true);
    }
    async acquireWifiFingerprint(ensureIsNew = true) {
        const ready = await this.isReady();
        if (!ready) {
            throw new Error("Could not acquire wifi fingerprint. Insufficient permissions or disabled location services. Please, call prepare() first before requesting a fingerprint.");
        }
        try {
            await this.setupScanReceiver();
            return this.getLastFingerprint(true);
        }
        catch (err) {
            if (ensureIsNew)
                throw err;
            return this.getLastFingerprint(false);
        }
    }
    setupScanReceiver() {
        return new Promise((resolve, reject) => {
            const scanReceiver = new es.uji.geotec.contextapis.wifi.WifiScanReceiver(new es.uji.geotec.contextapis.wifi.WifiScanReceiverDelegate({
                onReceive(context, intent) {
                    Utils.android
                        .getApplicationContext()
                        .unregisterReceiver(scanReceiver);
                    const success = intent.getBooleanExtra(android.net.wifi.WifiManager.EXTRA_RESULTS_UPDATED, false);
                    if (success) {
                        resolve();
                    }
                    else {
                        reject(new Error("Results not updated"));
                    }
                },
            }));
            const intentFilter = new android.content.IntentFilter();
            intentFilter.addAction(android.net.wifi.WifiManager.SCAN_RESULTS_AVAILABLE_ACTION);
            Utils.android
                .getApplicationContext()
                .registerReceiver(scanReceiver, intentFilter);
            const success = this.wifiManager.startScan();
            if (!success) {
                reject(new Error("Could not start scan! Reason: too many requests, device idle or unlikely hardware failure"));
            }
        });
    }
    getLastFingerprint(updateReceived) {
        const results = this.wifiManager.getScanResults();
        return {
            seen: getSeenWifiApsFrom(results),
            isNew: updateReceived,
            timestamp: new Date(),
        };
    }
}
//# sourceMappingURL=adapter.js.map